@@ -77,7 +77,7 @@ struct _AtkRoleItem
   gchar   *name;
 };
 
-static AtkRoleItem role_items [] =
+static const AtkRoleItem role_items [] =
 {
   { ATK_ROLE_INVALID, N_("invalid")},
   { ATK_ROLE_ACCEL_LABEL, N_("accelerator label")},
@@ -155,7 +155,15 @@ static AtkRoleItem role_items [] =
   { ATK_ROLE_APPLICATION, N_("application")},
   { ATK_ROLE_AUTOCOMPLETE, N_("autocomplete")},
   { ATK_ROLE_EDITBAR, N_("edit bar")},
-  { ATK_ROLE_EMBEDDED, N_("embedded component")}
+  { ATK_ROLE_EMBEDDED, N_("embedded component")},
+  { ATK_ROLE_ENTRY, N_("entry")},
+  { ATK_ROLE_CHART, N_("chart")},
+  { ATK_ROLE_CAPTION, N_("caption")},
+  { ATK_ROLE_DOCUMENT_FRAME, N_("document frame")},
+  { ATK_ROLE_HEADING, N_("heading")},
+  { ATK_ROLE_PAGE, N_("page")},
+  { ATK_ROLE_SECTION, N_("section")},
+  { ATK_ROLE_REDUNDANT_OBJECT, N_("redundant object")}
 };
 
 static void            atk_object_class_init        (AtkObjectClass  *klass);
@@ -208,21 +216,21 @@ static guint atk_object_signals[LAST_SIGNAL] = { 0, };
 
 static gpointer parent_class = NULL;
 
-static const gchar* atk_object_name_property_name = "accessible-name";
-static const gchar* atk_object_name_property_description = "accessible-description";
-static const gchar* atk_object_name_property_parent = "accessible-parent";
-static const gchar* atk_object_name_property_value = "accessible-value";
-static const gchar* atk_object_name_property_role = "accessible-role";
-static const gchar* atk_object_name_property_component_layer = "accessible-component-layer";
-static const gchar* atk_object_name_property_component_mdi_zorder = "accessible-component-mdi-zorder";
-static const gchar* atk_object_name_property_table_caption = "accessible-table-caption";
-static const gchar* atk_object_name_property_table_column_description = "accessible-table-column-description";
-static const gchar* atk_object_name_property_table_column_header = "accessible-table-column-header";
-static const gchar* atk_object_name_property_table_row_description = "accessible-table-row-description";
-static const gchar* atk_object_name_property_table_row_header = "accessible-table-row-header";
-static const gchar* atk_object_name_property_table_summary = "accessible-table-summary";
-static const gchar* atk_object_name_property_table_caption_object = "accessible-table-caption-object";
-static const gchar* atk_object_name_property_hypertext_num_links = "accessible-hypertext-nlinks";
+static const gchar* const atk_object_name_property_name = "accessible-name";
+static const gchar* const atk_object_name_property_description = "accessible-description";
+static const gchar* const atk_object_name_property_parent = "accessible-parent";
+static const gchar* const atk_object_name_property_value = "accessible-value";
+static const gchar* const atk_object_name_property_role = "accessible-role";
+static const gchar* const atk_object_name_property_component_layer = "accessible-component-layer";
+static const gchar* const atk_object_name_property_component_mdi_zorder = "accessible-component-mdi-zorder";
+static const gchar* const atk_object_name_property_table_caption = "accessible-table-caption";
+static const gchar* const atk_object_name_property_table_column_description = "accessible-table-column-description";
+static const gchar* const atk_object_name_property_table_column_header = "accessible-table-column-header";
+static const gchar* const atk_object_name_property_table_row_description = "accessible-table-row-description";
+static const gchar* const atk_object_name_property_table_row_header = "accessible-table-row-header";
+static const gchar* const atk_object_name_property_table_summary = "accessible-table-summary";
+static const gchar* const atk_object_name_property_table_caption_object = "accessible-table-caption-object";
+static const gchar* const atk_object_name_property_hypertext_num_links = "accessible-hypertext-nlinks";
 
 #ifdef G_OS_WIN32
 
@@ -232,11 +240,21 @@ static const gchar* atk_object_name_property_hypertext_num_links = "accessible-h
 
 G_WIN32_DLLMAIN_FOR_DLL_NAME(static, dll_name)
 
-static char *
+static const char *
 get_atk_locale_dir (void)
 {
-  return g_win32_get_package_installation_subdirectory
-    (GETTEXT_PACKAGE, dll_name, "lib/locale");
+  static gchar *atk_localedir = NULL;
+
+  if (!atk_localedir)
+    {
+      gchar temp;
+
+      temp = g_win32_get_package_installation_subdirectory
+        (GETTEXT_PACKAGE, dll_name, "lib\\locale");
+      atk_localedir = g_win32_locale_filename_from_utf8 (temp);
+      g_free (temp);
+    }
+  return atk_localedir;
 }
 
 #endif
@@ -1007,6 +1025,29 @@ atk_implementor_ref_accessible (AtkImplementor *object)
   return accessible;
 }
 
+    	
+/**
+ * Get a list of properties applied to this object as a whole, as an #AtkAttributeSet consisting of 
+ * name-value pairs. As such these attributes may be considered weakly-typed properties or annotations, 
+ * as distinct from strongly-typed object data available via other get/set methods.
+ * Not all objects have explicit "name-value pair" #AtkAttributeSet properties.
+ * @Since ATK 1.12
+ */
+AtkAttributeSet *
+atk_object_get_attributes (AtkObject                  *accessible)
+{
+  AtkObjectClass *klass;
+
+  g_return_val_if_fail (ATK_IS_OBJECT (accessible), NULL);
+
+  klass = ATK_OBJECT_GET_CLASS (accessible);
+  if (klass->get_attributes)
+    return (klass->get_attributes) (accessible); 
+  else 
+    return NULL;
+	
+}
+
 static AtkRelationSet*
 atk_object_real_ref_relation_set (AtkObject *accessible)
 {
