@@ -20,9 +20,10 @@
 #include "atkutil.h"
 #include "atkmarshal.c"
 
-
 static void atk_util_class_init (AtkUtilClass *klass);
 
+static AtkObject *previous_focus_object = NULL;
+
 GType
 atk_util_get_type (void)
 {
@@ -80,7 +81,7 @@ struct _FocusTracker {
 
 /**
  * atk_focus_tracker_init:
- * @add_function: Function to be called for focus tracker initialization
+ * @init: Function to be called for focus tracker initialization
  *
  * Specifies the function to be called for focus tracker initialization.
  * This function should be called by an implementation of the
@@ -174,7 +175,6 @@ void
 atk_focus_tracker_notify (AtkObject       *object)
 {
   FocusTracker *item;
-  static AtkObject *previous_focus_object = NULL;
   guint i;
 
   if (trackers == NULL)
@@ -317,6 +317,19 @@ atk_get_root (void)
   return retval;
 }
 
+/**
+ * atk_get_focus_object:
+ *
+ * Gets the currently focused object.
+ *
+ * Returns: the currently focused object for the current application
+ **/
+AtkObject*
+atk_get_focus_object (void)
+{
+  return previous_focus_object;
+}
+
 /**
  * atk_get_toolkit_name:
  *
